@@ -160,7 +160,7 @@ def peak_height(pk,M,omega_m,window_function,*filter_args):
 
     return(peak_height)
 
-def Casper(M,pk,omega_m,return_peak_height=False):
+def casper(M,pk,omega_m,return_peak_height=False):
     """
 
     Function to calculate the concentration and shape parameter for a given
